@@ -6,8 +6,8 @@ from . import views
 
 app_name = 'nautobot_evpn'
 urlpatterns = [
-    path(r'<uuid:pk>/vlan-link/add/', views.ConnectVRFView.as_view(), name='connect-vrf'),
-    path(r'<uuid:pk>/vlan-link/delete/', views.DisconnectVRFView.as_view(), name='disconnect-vrf'),
+    path(r'<uuid:pk>/vlan-link/add/', views.VRFPrimaryVLANView.as_view(), name='connect-vrf'),
+    path(r'<uuid:pk>/vlan-link/delete/', views.VRFDisconnectPrimaryVLANView.as_view(), name='disconnect-vrf'),
     path(r'vrf-link/<uuid:pk>/add/', views.AddVRFView.as_view(), name='add-vrf'),
     path(r'vrf-link/<uuid:pk>/delete/', views.RemoveVRFView.as_view(), name='remove-vrf'),
     path(r'anycast-ips/<uuid:pk>/add/', views.VLANAnycastIPView.as_view(), name='anycast-ips'),
