@@ -11,12 +11,12 @@ from nautobot.core.views.generic import BulkImportView, ObjectListView, ObjectEd
 
 from . import tables
 from .forms import (
-    VLANAddVRFForm, VLANAnycastIPForm, VLANVRFForm, JoinEthernetSegmentForm,
+    VLANAddToVRFForm, VLANAnycastIPForm, VRFPrimaryVLANForm, JoinEthernetSegmentForm,
     EthernetSegmentForm, EthernetSegmentCSVForm,
     EthernetSegmentMembershipCSVForm
 )
 from .models import (
-    AnycastIP, AnycastDummyIP, VLANVRF, VLANVRFList, EthernetSegment, EthernetSegmentMembership, Interface
+    AnycastIP, AnycastDummyIP, VRFPrimaryVLAN, VLANVRFList, EthernetSegment, EthernetSegmentMembership, Interface
 )
 from .utilities import redirect_to_referer
 
@@ -24,12 +24,12 @@ logger = logging.getLogger('nautobot.evpn')
 
 
 @method_decorator(login_required, name='dispatch')
-class DisconnectVRFView(View):
+class VRFDisconnectPrimaryVLANView(View):
     def get(self, request, pk=None):
         """
         This view disconnects a VRF from a VLAN.
         """
-        vlanvrf = get_object_or_404(VLANVRF, vrf_id=pk)
+        vlanvrf = get_object_or_404(VRFPrimaryVLAN, vrf_id=pk)
         vlanvrf.delete()
         messages.info(request, "Deleted VLAN-VRF connection.")
         return redirect_to_referer(request)
@@ -42,9 +42,9 @@ class CreateWithReturnView(CreateView):
         return context
 
 
-class ConnectVRFView(PermissionRequiredMixin, CreateWithReturnView):
-    model = VLANVRF
-    form_class = VLANVRFForm
+class VRFPrimaryVLANView(PermissionRequiredMixin, CreateWithReturnView):
+    model = VRFPrimaryVLAN
+    form_class = VRFPrimaryVLANForm
     permission_required = 'ipam.change_vrf'
 
     def get_success_url(self):
@@ -70,7 +70,7 @@ class RemoveVRFView(View):
 
 class AddVRFView(PermissionRequiredMixin, CreateWithReturnView):
     model = VLANVRFList
-    form_class = VLANAddVRFForm
+    form_class = VLANAddToVRFForm
     permission_required = 'ipam.change_vlan'
 
     def get_success_url(self):
